@@ -1,13 +1,15 @@
 package Taskwarrior::Kusarigama::Plugin::Command::AndAfter;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: create a subsequent task
-$Taskwarrior::Kusarigama::Plugin::Command::AndAfter::VERSION = '0.9.3';
+$Taskwarrior::Kusarigama::Plugin::Command::AndAfter::VERSION = '0.10.0';
 
 use 5.10.0;
 
 use strict;
 use warnings;
 
+use PerlX::Maybe;
+
 use Moo;
 
 extends 'Taskwarrior::Kusarigama::Plugin';
@@ -17,14 +19,16 @@ with 'Taskwarrior::Kusarigama::Hook::OnCommand';
 sub on_command {
     my $self = shift;
 
-    my $select = $self->pre_command_args 
-        || ( $self->run_task->export( [ '+LATEST' ] ) )[0]->{uuid};
+    my( $previous ) = $self->run_task->export( [
+        $self->pre_command_args || '+LATEST'
+    ]);
 
-    $self->run_task->add( $self->post_command_args, { depends => $select } );
+    $self->run_task->add(  { 
+        maybe project => $previous->{project},
+        depends => $previous->{uuid} 
+    }, $self->post_command_args );
 
-    say for $self->run_task->list(
-        $self->run_task->_id( '+LATEST' )
-    );
+    say for $self->run_task->list( '+LATEST' );
 };
 
 1;
@@ -41,7 +45,7 @@ Taskwarrior::Kusarigama::Plugin::Command::AndAfter - create a subsequent task
 
 =head1 VERSION
 
-version 0.9.3
+version 0.10.0
 
 =head1 SYNOPSIS
 
@@ -49,8 +53,9 @@ version 0.9.3
 
 =head1 DESCRIPTION 
 
-Creates a task that depends on the give task(s). If no previous task is 
-provided, defaults to C<+LATEST>.
+Creates a task that depends on the given task(s). If no previous task is 
+provided, defaults to C<+LATEST>. If no project is explicitly given for the 
+next task, it inherits the project of the previous task.
 
 =head1 AUTHOR
 
